about summary refs log tree commit diff
path: root/pkgs/development/haskell-modules/configuration-common.nix
diff options
context:
space:
mode:
authormaralorn <mail@maralorn.de>2023-10-05 00:45:07 +0200
committermaralorn <mail@maralorn.de>2023-10-05 00:45:07 +0200
commit98262d4eeec84e2b2c9912f4dd0bdfb305f1e858 (patch)
treebd2e6639ee49b924439ee830644878427a230ae2 /pkgs/development/haskell-modules/configuration-common.nix
parent88c66e9a9616211606471509cb5c7f3d37378a9b (diff)
haskellPackages: Update hspec pins
Diffstat (limited to 'pkgs/development/haskell-modules/configuration-common.nix')
-rw-r--r--pkgs/development/haskell-modules/configuration-common.nix26
1 files changed, 13 insertions, 13 deletions
diff --git a/pkgs/development/haskell-modules/configuration-common.nix b/pkgs/development/haskell-modules/configuration-common.nix
index 681c3dea2f77b..d0633e088c610 100644
--- a/pkgs/development/haskell-modules/configuration-common.nix
+++ b/pkgs/development/haskell-modules/configuration-common.nix
@@ -57,15 +57,15 @@ self: super: {
           # not solvable short of recompiling GHC. Instead of adding
           # allowInconsistentDependencies for all reverse dependencies of hspec-core,
           # just upgrade to an hspec version without the offending dependency.
-          hspec-core = cself.hspec-core_2_11_4;
-          hspec-discover = cself.hspec-discover_2_11_4;
-          hspec = cself.hspec_2_11_4;
+          hspec-core = cself.hspec-core_2_11_5;
+          hspec-discover = cself.hspec-discover_2_11_5;
+          hspec = cself.hspec_2_11_5;
 
           # hspec-discover and hspec-core depend on hspec-meta for testing which
           # we need to avoid since it depends on ghc as well. Since hspec*_2_11*
           # are overridden to take the versioned attributes as inputs, we need
           # to make sure to override the versioned attribute with this fix.
-          hspec-discover_2_11_4 = dontCheck csuper.hspec-discover_2_11_4;
+          hspec-discover_2_11_5 = dontCheck csuper.hspec-discover_2_11_5;
 
           # Prevent dependency on doctest which causes an inconsistent dependency
           # due to depending on ghc which depends on directory etc.
@@ -215,7 +215,7 @@ self: super: {
 
   # 2023-08-09: Jailbreak because of vector < 0.13
   monad-bayes = doJailbreak (super.monad-bayes.override {
-    hspec = self.hspec_2_11_4;
+    hspec = self.hspec_2_11_5;
   });
 
   # Disable tests failing on odd floating point numbers generated by QuickCheck 2.14.3
@@ -1706,19 +1706,19 @@ self: super: {
   servant-openapi3 = dontCheck super.servant-openapi3;
 
   # Give latest hspec correct dependency versions without overrideScope
-  hspec_2_11_4 = doDistribute (super.hspec_2_11_4.override {
-    hspec-discover = self.hspec-discover_2_11_4;
-    hspec-core = self.hspec-core_2_11_4;
+  hspec_2_11_5 = doDistribute (super.hspec_2_11_5.override {
+    hspec-discover = self.hspec-discover_2_11_5;
+    hspec-core = self.hspec-core_2_11_5;
   });
-  hspec-meta_2_11_4 = doDistribute (super.hspec-meta_2_11_4.override {
+  hspec-meta_2_11_5 = doDistribute (super.hspec-meta_2_11_5.override {
     hspec-expectations = self.hspec-expectations_0_8_4;
   });
-  hspec-discover_2_11_4 = doDistribute (super.hspec-discover_2_11_4.override {
-    hspec-meta = self.hspec-meta_2_11_4;
+  hspec-discover_2_11_5 = doDistribute (super.hspec-discover_2_11_5.override {
+    hspec-meta = self.hspec-meta_2_11_5;
   });
   # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_4
   # is overlayed to hspec-core.
-  hspec-core_2_11_4 = doDistribute (dontCheck (super.hspec-core_2_11_4.override {
+  hspec-core_2_11_5 = doDistribute (dontCheck (super.hspec-core_2_11_5.override {
     hspec-expectations = self.hspec-expectations_0_8_4;
   }));
@@ -1706,19 +1706,19 @@ self: super: {
   });
-  # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_4
+  # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_5
   # is overlayed to hspec-core.